@@ -18,11 +18,11 @@
 
 #include "config.h"
 
-#include <QAction>
 #include <QtGlobal>
+#include <QAction>
+#include <QIcon>
 
 #include <KLocalizedString>
-#include <KIconLoader>
 #include <KMainWindow>
 
 #include "libkwave/FileInfo.h"
@@ -50,19 +50,19 @@
 Kwave::PlayerToolBar::PlayerToolBar(KMainWindow *parent, const QString &name,
                                     Kwave::MenuManager &menu_manager)
     :KToolBar(name, parent, true),
-     m_context(0),
-     m_action_prev(0),
-     m_action_rewind(0),
-     m_action_record(0),
-     m_action_play(0),
-     m_action_loop(0),
-     m_action_pause(0),
-     m_action_stop(0),
-     m_action_forward(0),
-     m_action_next(0),
-     m_pause_timer(0),
+     m_context(Q_NULLPTR),
+     m_action_prev(),
+     m_action_rewind(Q_NULLPTR),
+     m_action_record(Q_NULLPTR),
+     m_action_play(Q_NULLPTR),
+     m_action_loop(Q_NULLPTR),
+     m_action_pause(Q_NULLPTR),
+     m_action_stop(Q_NULLPTR),
+     m_action_forward(Q_NULLPTR),
+     m_action_next(Q_NULLPTR),
+     m_pause_timer(Q_NULLPTR),
      m_blink_on(false),
-     m_playback(0),
+     m_playback(Q_NULLPTR),
      m_menu_manager(menu_manager),
      m_labels(),
      m_last_tracks(0),
@@ -70,60 +70,48 @@ Kwave::PlayerToolBar::PlayerToolBar(KMainWindow *parent, const QString &name,
      m_last_visible(0),
      m_last_length(0)
 {
-    KIconLoader icon_loader;
-    const int max_s = KIconLoader::SizeEnormous;
-
     m_action_prev = addAction(
-	icon_loader.loadIcon(_("kwave_player_start"),
-	                     KIconLoader::Toolbar, max_s),
+	QIcon::fromTheme(_("kwave_player_start")),
 	i18n("Previous"),
 	this, SLOT(toolbarRewindPrev()));
 
     m_action_rewind = addAction(
-	icon_loader.loadIcon(_("kwave_player_rew"),
-	                     KIconLoader::Toolbar, max_s),
+	QIcon::fromTheme(_("kwave_player_rew")),
 	i18n("Rewind"),
 	this, SLOT(toolbarRewind()));
 
     m_action_record = addAction(
-	icon_loader.loadIcon(_("kwave_player_record"),
-	                     KIconLoader::Toolbar, max_s),
+	QIcon::fromTheme(_("kwave_player_record")),
 	i18n("Record"),
 	this, SLOT(toolbarRecord()));
 
     m_action_play = addAction(
-	icon_loader.loadIcon(_("kwave_player_play"),
-	                     KIconLoader::Toolbar, max_s),
+	QIcon::fromTheme(_("kwave_player_play")),
 	i18n("Start playback"),
 	this, SLOT(toolbarStart()));
 
     m_action_loop = addAction(
-	icon_loader.loadIcon(_("kwave_player_loop"),
-	                     KIconLoader::Toolbar, max_s),
+	QIcon::fromTheme(_("kwave_player_loop")),
 	i18n("Start playback and loop"),
 	this, SLOT(toolbarLoop()));
 
     m_action_pause = addAction(
-	icon_loader.loadIcon(_("kwave_player_pause"),
-	                     KIconLoader::Toolbar, max_s),
+	QIcon::fromTheme(_("kwave_player_pause")),
 	QString(),
 	this, SLOT(toolbarPause()));
 
     m_action_stop = addAction(
-	icon_loader.loadIcon(_("kwave_player_stop"),
-	                     KIconLoader::Toolbar, max_s),
+	QIcon::fromTheme(_("kwave_player_stop")),
 	i18n("Stop playback or loop"),
 	this, SLOT(toolbarStop()));
 
     m_action_forward = addAction(
-	icon_loader.loadIcon(_("kwave_player_fwd"),
-	                     KIconLoader::Toolbar, max_s),
+	QIcon::fromTheme(_("kwave_player_fwd")),
 	i18n("Forward"),
 	this, SLOT(toolbarForward()));
 
     m_action_next = addAction(
-	icon_loader.loadIcon(_("kwave_player_end"),
-	                     KIconLoader::Toolbar, max_s),
+	QIcon::fromTheme(_("kwave_player_end")),
 	i18n("Next"),
 	this, SLOT(toolbarForwardNext()));
 
@@ -135,8 +123,8 @@ Kwave::PlayerToolBar::PlayerToolBar(KMainWindow *parent, const QString &name,
 Kwave::PlayerToolBar::~PlayerToolBar()
 {
     if (m_pause_timer) delete m_pause_timer;
-    m_pause_timer = 0;
-    m_context = 0;
+    m_pause_timer = Q_NULLPTR;
+    m_context = Q_NULLPTR;
 }
 
 //***************************************************************************
@@ -163,8 +151,9 @@ void Kwave::PlayerToolBar::contextSwitched(Kwave::FileContext *context)
     // use the new context
     m_context = context;
 
-    Kwave::SignalManager *signal = m_context ? m_context->signalManager() : 0;
-    m_playback = (signal) ? &signal->playbackController() : 0;
+    Kwave::SignalManager *signal =
+        (m_context) ? m_context->signalManager() : Q_NULLPTR;
+    m_playback = (signal) ? &signal->playbackController() : Q_NULLPTR;
 
     // connect the playback controller of the new context
     if (m_context && m_playback) {
@@ -189,7 +178,7 @@ void Kwave::PlayerToolBar::contextSwitched(Kwave::FileContext *context)
 void Kwave::PlayerToolBar::contextDestroyed(Kwave::FileContext *context)
 {
     if (context != m_context) return; // not of interest
-    contextSwitched(0);
+    contextSwitched(Q_NULLPTR);
 }
 
 //***************************************************************************
@@ -315,18 +304,13 @@ void Kwave::PlayerToolBar::toolbarStop()
 //***************************************************************************
 void Kwave::PlayerToolBar::blinkPause()
 {
-    KIconLoader icon_loader;
-    const int max_s   = KIconLoader::SizeEnormous;
     const bool paused = m_playback && m_playback->paused();
 
     Q_ASSERT(m_action_pause);
     if (!m_action_pause) return;
 
-    m_action_pause->setIcon(icon_loader.loadIcon(
-	_((paused && m_blink_on) ?
-	    "kwave_player_pause_2" : "kwave_player_pause"),
-	KIconLoader::Toolbar, max_s)
-    );
+    m_action_pause->setIcon(QIcon::fromTheme(_((paused && m_blink_on) ?
+	"kwave_player_pause_2" : "kwave_player_pause")));
 
     m_blink_on = !m_blink_on;
 }
@@ -464,7 +448,7 @@ void Kwave::PlayerToolBar::updateState()
 	// stop blinking
 	m_pause_timer->stop();
 	delete m_pause_timer;
-	m_pause_timer = 0;
+        m_pause_timer = Q_NULLPTR;
 
 	m_blink_on = false;
 	blinkPause();
