@@ -67,7 +67,7 @@ Kwave::SignalView::SignalView(QWidget *parent, QWidget *controls,
      m_position_widget(this),
      m_position_widget_timer(this),
      m_siblings(),
-     m_selected_item(0)
+     m_selected_item(Q_NULLPTR)
 {
     // connect the timer of the position widget
     connect(&m_position_widget_timer, SIGNAL(timeout()),
@@ -173,7 +173,7 @@ double Kwave::SignalView::samples2ms(sample_index_t samples)
 Kwave::SignalView::SelectionPos Kwave::SignalView::selectionPosition(int x)
 {
     // shortcut: if this view can't handle selection...
-    if (!canHandleSelection()) return 0;
+    if (!canHandleSelection()) return Q_NULLPTR;
 
     Q_ASSERT(m_signal_manager);
     if (!m_signal_manager) return None;
@@ -215,7 +215,7 @@ bool Kwave::SignalView::isInSelection(int x)
 QSharedPointer<Kwave::ViewItem> Kwave::SignalView::findItem(const QPoint &pos)
 {
     Q_UNUSED(pos);
-    return QSharedPointer<Kwave::ViewItem>(0);
+    return QSharedPointer<Kwave::ViewItem>(Q_NULLPTR);
 }
 
 //***************************************************************************
@@ -286,7 +286,7 @@ void Kwave::SignalView::showPosition(const QString &text, sample_index_t pos,
 //***************************************************************************
 void Kwave::SignalView::findNewItem(const QPoint &mouse_pos, bool active)
 {
-    m_selected_item = QSharedPointer<Kwave::ViewItem>(0);
+    m_selected_item = QSharedPointer<Kwave::ViewItem>(Q_NULLPTR);
     if (!active) m_mouse_mode = MouseNormal;
 
     m_selected_item = findItem(mouse_pos);
@@ -531,7 +531,7 @@ void Kwave::SignalView::keyPressEvent(QKeyEvent *e)
 	// Cancel key (Escape) -> reset all view item operations
 	m_mouse_mode = MouseNormal;
 	setCursor(Qt::ArrowCursor);
-	m_selected_item = QSharedPointer<Kwave::ViewItem>(0);
+        m_selected_item = QSharedPointer<Kwave::ViewItem>(Q_NULLPTR);
     } else {
 	QWidget::keyPressEvent(e);
     }
@@ -603,7 +603,7 @@ void Kwave::SignalView::dropEvent(QDropEvent *event)
 	bool first = true;
 	foreach (const QUrl &url, mime_data->urls()) {
 	    QString filename = url.toLocalFile();
-	    QString mimetype = Kwave::CodecManager::whatContains(url);
+            QString mimetype = Kwave::CodecManager::mimeTypeOf(url);
 	    if (Kwave::CodecManager::canDecode(mimetype)) {
 		if (first) {
 		    // first dropped URL -> open in this window
@@ -684,7 +684,7 @@ void Kwave::SignalView::dragMoveEvent(QDragMoveEvent *event)
 //***************************************************************************
 //***************************************************************************
 Kwave::SignalView::PositionWidget::PositionWidget(QWidget *parent)
-    :QWidget(parent), m_label(0), m_alignment(0),
+    :QWidget(parent), m_label(Q_NULLPTR), m_alignment(Q_NULLPTR),
      m_radius(10), m_arrow_length(30), m_last_alignment(Qt::AlignHCenter),
      m_last_size(QSize(0,0)), m_polygon()
 {
@@ -710,7 +710,7 @@ Kwave::SignalView::PositionWidget::PositionWidget(QWidget *parent)
 Kwave::SignalView::PositionWidget::~PositionWidget()
 {
     if (m_label) delete m_label;
-    m_label = 0;
+    m_label = Q_NULLPTR;
 }
 
 //***************************************************************************
