@@ -43,7 +43,7 @@ Kwave::PlaybackController::PlaybackController(
     Kwave::SignalManager &signal_manager
 )
     :m_signal_manager(signal_manager), m_thread(this, QVariant()),
-     m_device(0), m_lock_device(), m_playback_params(),
+     m_device(Q_NULLPTR), m_lock_device(), m_playback_params(),
      m_lock_playback(), m_should_seek(false), m_seek_pos(0),
      m_track_selection_changed(false),
      m_reload_mode(false), m_loop_mode(false), m_paused(false),
@@ -318,7 +318,7 @@ void Kwave::PlaybackController::startDevicePlayBack()
 	qWarning("PlaybackController::startDevicePlayBack(): "
 	         "removing stale instance");
 	delete m_device;
-	m_device = 0;
+        m_device = Q_NULLPTR;
     }
 
     // open the device and abort if not possible
@@ -400,7 +400,7 @@ void Kwave::PlaybackController::run_wrapper(const QVariant &params)
 {
     Q_UNUSED(params);
 
-    Kwave::MixerMatrix *mixer = 0;
+    Kwave::MixerMatrix *mixer = Q_NULLPTR;
     sample_index_t first      = m_playback_start;
     sample_index_t last       = m_playback_end;
     unsigned int out_channels = m_playback_params.channels;
@@ -455,7 +455,7 @@ void Kwave::PlaybackController::run_wrapper(const QVariant &params)
 		// check for track selection change (need for new mixer)
 		if (m_track_selection_changed) {
 		    if (mixer) delete mixer;
-		    mixer = 0;
+                    mixer = Q_NULLPTR;
 		    m_track_selection_changed = false;
 		}
 
@@ -541,13 +541,13 @@ void Kwave::PlaybackController::run_wrapper(const QVariant &params)
 //***************************************************************************
 void Kwave::PlaybackController::closeDevice()
 {
-    Kwave::PlayBackDevice *dev = 0;
+    Kwave::PlayBackDevice *dev = Q_NULLPTR;
     if (m_device) {
 	// NOTE: we could get a recursion here if we delete with the lock
 	//       held, if the device calls processEvents during shutdown
 	QMutexLocker lock_for_delete(&m_lock_device);
 	dev = m_device;
-	m_device = 0;
+        m_device = Q_NULLPTR;
     }
     delete dev;
 }
@@ -592,7 +592,7 @@ Kwave::PlayBackDevice *Kwave::PlaybackController::createDevice(
     Kwave::playback_method_t method)
 {
     // locate the corresponding playback device factory (plugin)
-    Kwave::PlaybackDeviceFactory *factory = 0;
+    Kwave::PlaybackDeviceFactory *factory = Q_NULLPTR;
     foreach (Kwave::PlaybackDeviceFactory *f, m_playback_factories) {
 	Q_ASSERT(f);
 	if (f && f->supportedMethods().contains(method)) {
@@ -600,7 +600,7 @@ Kwave::PlayBackDevice *Kwave::PlaybackController::createDevice(
 	    break;
 	}
     }
-    if (!factory) return 0;
+    if (!factory) return Q_NULLPTR;
 
     // create a new device instance, using the given method
     return factory->createDevice(method);
@@ -630,7 +630,7 @@ Kwave::PlayBackDevice *Kwave::PlaybackController::openDevice(
 
     // try to create a new device, using the given playback method
     Kwave::PlayBackDevice *device = createDevice(params.method);
-    if (!device) return 0;
+    if (!device) return Q_NULLPTR;
 
     // override the number of tracks if not negative
     if (tracks > 0) params.channels = tracks;
@@ -649,7 +649,7 @@ Kwave::PlayBackDevice *Kwave::PlaybackController::openDevice(
 
 	// delete the device if it did not open
 	delete device;
-	device = 0;
+        device = Q_NULLPTR;
 
 	// show an error message box
 	Kwave::MessageBox::error(m_signal_manager.parentWidget(), result,
