@@ -41,7 +41,7 @@ namespace Kwave
 	explicit WorkerThread(Kwave::Runnable *runnable, QVariant params);
 
 	/** Destructor, calls stop() if the thread is still running. */
-	virtual ~WorkerThread();
+        virtual ~WorkerThread() Q_DECL_OVERRIDE;
 
 	/** Starts the thread's execution. */
 	virtual void start();
@@ -59,7 +59,7 @@ namespace Kwave
 	 * A wrapper for the run() function, calls the run_wrapper(...)
 	 * of m_runnable with the parameters passed in the constructor.
 	 */
-	void run() Q_DECL_OVERRIDE;
+        virtual void run() Q_DECL_OVERRIDE;
 
 	/**
 	 * Sets an internal flag that signals the worker thread to cancel,
