@@ -59,7 +59,7 @@ Kwave::PlayBackDialog::PlayBackDialog(
 )
     :QDialog(p.parentWidget()), PlayBackDlg(),
      m_playback_controller(playback_controller),
-     m_device(0),
+     m_device(Q_NULLPTR),
      m_playback_params(params),
      m_methods_map(),
      m_file_filter(_("")),
@@ -157,7 +157,7 @@ void Kwave::PlayBackDialog::setMethod(Kwave::playback_method_t method)
 
     // change the playback method (class PlayBackDevice)
     if (m_device) delete m_device;
-    m_device = 0;
+    m_device = Q_NULLPTR;
 
     // remember the device selection, just for the GUI
     // for the next time this method gets selected
@@ -289,7 +289,7 @@ void Kwave::PlayBackDialog::setSupportedDevices(QStringList devices)
 
     if (devices.contains(_("#TREE#"))) {
 	// treeview mode
-	KIconLoader icon_loader;
+	KIconLoader *icon_loader = KIconLoader::global();
 
 	devices.removeAll((_("#TREE#")));
 	listDevices->setEnabled(true);
@@ -299,12 +299,12 @@ void Kwave::PlayBackDialog::setSupportedDevices(QStringList devices)
 
 	// build a tree with all nodes in the list
 	foreach (const QString &dev_id, devices) {
-	    QTreeWidgetItem *parent = 0;
+            QTreeWidgetItem *parent = Q_NULLPTR;
 
 	    QStringList list = dev_id.split(_("||"), QString::KeepEmptyParts);
 	    foreach (const QString &t, list) {
 		QString token(t);
-		QTreeWidgetItem *item = 0;
+                QTreeWidgetItem *item = Q_NULLPTR;
 
 		// split the icon name from the token
 		QString icon_name;
@@ -360,8 +360,8 @@ void Kwave::PlayBackDialog::setSupportedDevices(QStringList devices)
 		    }
 		}
 
-		if (item && icon_name.length()) {
-		    QIcon icon = icon_loader.loadIcon(
+		if (item && icon_name.length() && icon_loader) {
+		    QIcon icon = icon_loader->loadIcon(
 			icon_name, KIconLoader::User);
 		    item->setIcon(0, icon);
 		}
@@ -440,7 +440,7 @@ void Kwave::PlayBackDialog::setDevice(const QString &device)
 
     if (listDevices->isEnabled()) {
 	// treeview mode
-	QTreeWidgetItem *node = m_devices_list_map.key(device, 0);
+        QTreeWidgetItem *node = m_devices_list_map.key(device, Q_NULLPTR);
 	if (node) {
 	    node->setSelected(true);
 	    listDevices->scrollToItem(node);
